pan-python
==========

``pan-python`` is a Python package for Palo Alto Networks
Next-Generation Firewalls, WildFire and AutoFocus.  It provides
several components:

- Python and command line interface to the PAN-OS and Panorama XML API
- Command line program for managing PAN-OS XML configurations
- Python and command line interface to the WildFire API
- Python and command line interface to the AutoFocus API
- Python and command line interface to the PAN-OS licensing API

Documentation
-------------

- Rendered reStructuredText from GitHub:

  https://github.com/kevinsteves/pan-python/tree/master/doc

- HTML from source distribution:

  doc/\*.html

Install
-------

``pan-python`` is available as a
`release <https://github.com/kevinsteves/pan-python/releases>`_
on GitHub and as a
`package <https://pypi.org/project/pan-python/>`_
on PyPi.

There are no external modules required to use ``pan-python``.
